@@ -38,7 +38,7 @@ class StickProtocol():
                                    cipher=identityKey['cipher'], salt=identityKey['salt'])
         SignedPreKey.objects.create(public=signedPreKey['public'], signature=signedPreKey["signature"],
                                     keyId=signedPreKey['id'], user=user, cipher=signedPreKey['cipher'],
-                                    salt=signedPreKey['salt'])
+                                    salt=signedPreKey['salt'], active=True)
         for preKey in preKeys:
             PreKey.objects.create(public=preKey['public'], keyId=preKey["id"], user=user, cipher=preKey['cipher'],
                                   salt=preKey['salt'])
@@ -435,6 +435,18 @@ class StickProtocol():
                                                forOneTimeId=oneTimeId, ofOneTimeId=user.oneTimeId)
 
 
+    def update_active_spk(self, data, user):
+        """
+        This method is used to update the active signed prekey for a user
+        """
+        old_spk = SignedPreKey.objects.get(user=user, active=True)
+        old_spk.active = False
+        old_spk.save()
+        SignedPreKey.objects.create(user=user, public=data['public'], signature=data["signature"],
+                                    keyId=data['id'], cipher=data['cipher'], salt=data['salt'], active=True)
+
+
+
     def verify_password_and_get_keys(self, data, user):
         """
         This Login method should be called after the user have verified their phone number and got their LimitedAccessToken.
